@@ -89,7 +89,7 @@ selpoint <- function(var, infile, outfile, lon1 = 0, lat1 = 0, format = "nc",
     stop("No lon/lat information found in file, please add by applying add_grid_info")
   }
 
-  # find closest point to target coordinates using sp package
+  # find closest point to target coordinates using fields package
   if (file_data$grid$is_regular) {
     dlon <- abs(file_data$dimension_data$x[1] - file_data$dimension_data$x[2])
     dlat <- abs(file_data$dimension_data$y[1] - file_data$dimension_data$y[2])
@@ -106,12 +106,11 @@ selpoint <- function(var, infile, outfile, lon1 = 0, lat1 = 0, format = "nc",
     lon2 <- file_data$dimension_data$x[lon_limit]
     lat2 <- file_data$dimension_data$y[lat_limit]
 
-    pos <- sp::SpatialPoints(cbind(lon1, lat1),
-                             proj4string = sp::CRS("+proj=longlat +datum=WGS84"))
     dum_dist <- 1000
     for (i in seq_along(lon2)) {
       for (j in seq_along(lat2)) {
-        dist <- sp::spDistsN1(pos, c(lon2[i], lat2[j]), longlat = FALSE)
+        dist <- fields::rdist.earth(x1 = cbind(lon1, lat1), x2 = cbind(lon2[i], lat2[j]),
+                                    miles = FALSE)
         if (dist <= dum_dist) {
           dum_dist <- dist
           dumi <- i
@@ -159,9 +158,9 @@ selpoint <- function(var, infile, outfile, lon1 = 0, lat1 = 0, format = "nc",
                                       by.y = c("row", "col"),
                                       out.class = matrix))
 
-    dist <- sp::spDistsN1(cbind(file_data$grid$vars_data[[LON_NAMES$DEFAULT]][lonlat_merge],
-                                file_data$grid$vars_data[[LAT_NAMES$DEFAULT]][lonlat_merge]),
-                          c(lon1, lat1), longlat = FALSE)
+    dist <- fields::rdist.earth(cbind(file_data$grid$vars_data[[LON_NAMES$DEFAULT]][lonlat_merge],
+                                     file_data$grid$vars_data[[LAT_NAMES$DEFAULT]][lonlat_merge]),
+                               cbind(lon1, lat1), miles = FALSE)
     mini <- which.min(dist)
     nearest <- lonlat_merge[mini, ]
 
